Linear Systems
=======================

.. contents::
    :depth: 2
    :local:

Triangular Systems
------------------------


.. currentmodule:: cr.nimble

.. autosummary::
  :toctree: _autosummary

    solve_Lx_b
    solve_LTx_b
    solve_Ux_b
    solve_UTx_b
    solve_spd_chol



Special Dense Linear Systems
------------------------------------------


.. autosummary::
    :toctree: _autosummary

    mult_with_submatrix
    solve_on_submatrix